import { Placeholder, SelectControl, PanelBody } from '@wordpress/components';
import ServerSideRender from '@wordpress/server-side-render';
import { InspectorControls } from '@wordpress/editor';
import { registerBlockType } from '@wordpress/blocks';

( function( settings ) {

	var blockID = 'thethemefoundry/happyforms';
	var options = settings.forms
		.map( function( form ) {
			return { label: form.post_title, value: form.ID };
		} )
	options.reverse().unshift( { label: settings.i18n.select_default, value: '' } );

	var ComponentPlaceholder = function( props ) {
		return (
			<Placeholder 
				icon={ settings.icon } 
				label={ settings.i18n.placeholder_text }
				className={ settings.i18n.placeholder_class }
				key="happyforms-component-placeholder">

				{ settings.forms.length > 0
					? <SelectControl value="" options={ options } onChange={ ( v ) => props.setAttributes( { id: v } ) } />
					: <p>{ settings.i18n.no_forms_found_text }</p>
				}

			</Placeholder>
		);
	};

	var ComponentForm = function( props ) {
		return [
			<ServerSideRender
				block={ blockID }
				attributes={ props.attributes }
				key="happyforms-component-form" />
		];
	};

	var ComponentInspector = function( props ) {
		return (
			<InspectorControls key="happyforms-inspector-controls">
				<PanelBody title={ settings.i18n.settings_title }>
					<SelectControl value={ props.attributes.id } options={ options } onChange={ ( v ) => props.setAttributes( { id : v } ) } />
				</PanelBody>
			</InspectorControls>
		);
	};

	registerBlockType( blockID, {
		title: settings.block.title,
		description: settings.block.description,
		category: settings.block.category,
		icon: settings.block.icon,
		keywords: settings.block.keywords,
		supports: {
			anchor: true,
			html: false
		},

		edit: function( props ) {
			if ( ! props.attributes.id && settings.forms.length === 1 ) {
				props.attributes.id = settings.forms[0].ID;
			}

			let blockComponent = (
				props.attributes.id ?
				ComponentForm( props ) :
				ComponentPlaceholder( props )
			);

			let inspectorComponent = (
				settings.forms.length > 1 ?
				ComponentInspector( props ) :
				false
			);
			
			let component = (
				inspectorComponent ? 
				[ blockComponent, inspectorComponent ] :
				[ blockComponent ]
			);

			return component;
		},

		save: function() {
			return null;
		},
	} );

} )(
	_happyFormsBlockSettings,
);